@@ -6,7 +6,7 @@ use warnings;
 use AnyEvent;
 use AnyEvent::Redis::RipeRedis;
 
-my $cv = AnyEvent->condvar();
+my $cv = AE::cv();
 
 my $redis = AnyEvent::Redis::RipeRedis->new(
   host => 'localhost',
@@ -33,7 +33,7 @@ $redis->eval_cached( 'return { KEYS[1], KEYS[2], ARGV[1], ARGV[2] }',
     2, 'key1', 'key2', 'first', 'second', {
   on_done => sub {
     my $data = shift;
-    foreach my $val ( @{ $data } ) {
+    foreach my $val ( @{$data}  ) {
       print "$val\n";
     }
     $cv->send();
